@@ -284,7 +284,7 @@ void GUIMain::DrawWithControls(Bitmap *ds)
 
 void GUIMain::DrawControls(Bitmap *ds)
 {
-    if ((GUI::Context.DisabledState != kGuiDis_Undefined) && (GUI::Options.DisabledStyle == kGuiDis_Blackout))
+    if (GUI::ShouldSkipControls(this))
         return; // don't draw GUI controls
 
     Bitmap tempbmp; // in case we need transforms
@@ -295,9 +295,12 @@ void GUIMain::DrawControls(Bitmap *ds)
         GUIObject *objToDraw = _controls[_ctrlDrawOrder[ctrl_index]];
         Size obj_size = objToDraw->GetSize();
 
-        if (!objToDraw->IsVisible() || (obj_size.Width <= 0 || obj_size.Height <= 0))
+        // Note that the control is invisible not only when Visible property is false,
+        // but also according to a combination of being disabled and some disabled gui modes
+        if (!GUI::IsGUIVisible(objToDraw))
             continue;
-        if (!objToDraw->IsEnabled() && (GUI::Options.DisabledStyle == kGuiDis_Blackout))
+        // Control's size is empty, no sense in drawing it
+        if (obj_size.IsNull())
             continue;
 
         if (GUI::Options.ClipControls && objToDraw->IsContentClipped())
@@ -778,13 +781,19 @@ String FixupGUIName272(const String &name)
     return name;
 }
 
+int CalcFontGraphicalHExtent(int font)
+{
+    const auto hextent = get_font_surface_hextent(font);
+    return hextent >= 0 ? 0 : hextent;
+}
+
 Line CalcFontGraphicalVExtent(int font)
 {
     // Following factors are affecting the graphical vertical metrics:
     // * font's real graphical extent (top and bottom offsets relative to the "pen")
     // * custom vertical offset set by user (if non-zero),
     const auto finfo = get_fontinfo(font);
-    const auto fextent = get_font_surface_extent(font);
+    const auto fextent = get_font_surface_vextent(font);
     int top = fextent.first +
         std::min(0, finfo.YOffset); // apply YOffset only if negative
     int bottom = fextent.second +
@@ -813,8 +822,9 @@ Point CalcTextPosition(const String &text, int font, const Rect &frame, FrameAli
     Rect rc = AlignInRect(frame, RectWH(0, 0, get_text_width_outlined(text.GetCStr(), font), use_height), align);
     if (gr_rect)
     {
+        int h_ext = CalcFontGraphicalHExtent(font);
         Line vextent = CalcFontGraphicalVExtent(font);
-        *gr_rect = RectWH(rc.Left, rc.Top + vextent.Y1, rc.GetWidth(), vextent.Y2 - vextent.Y1);
+        *gr_rect = RectWH(rc.Left + h_ext, rc.Top + vextent.Y1, rc.GetWidth() + (-h_ext) * 2, vextent.Y2 - vextent.Y1);
     }
     return rc.GetLT();
 }
@@ -830,8 +840,9 @@ Rect CalcTextGraphicalRect(const String &text, int font, const Point &at)
 {
     // Calc only width, and let CalcFontGraphicalVExtent() calc height
     int w = get_text_width_outlined(text.GetCStr(), font);
+    int h_ext = CalcFontGraphicalHExtent(font);
     Line vextent = CalcFontGraphicalVExtent(font);
-    return RectWH(at.X, at.Y + vextent.Y1, w, vextent.Y2 - vextent.Y1);
+    return RectWH(at.X + h_ext, at.Y + vextent.Y1, w + (-h_ext) * 2, vextent.Y2 - vextent.Y1);
 }
 
 Rect CalcTextGraphicalRect(const String &text, int font, const Rect &frame, FrameAlignment align)
@@ -866,8 +877,9 @@ Rect CalcTextGraphicalRect(const std::vector<String> &text, size_t item_count, i
     }
     // Include font fixes for the first and last text line,
     // in case graphical height is different, and there's a VerticalOffset
+    int h_ext = CalcFontGraphicalHExtent(font);
     Line vextent = GUI::CalcFontGraphicalVExtent(font);
-    Rect text_rc = RectWH(0, vextent.Y1, max_line.X2 - max_line.X1 + 1,
+    Rect text_rc = RectWH(h_ext, vextent.Y1, max_line.X2 - max_line.X1 + 1 + (-h_ext) * 2,
         at_y - linespace + (vextent.Y2 - vextent.Y1));
     return text_rc;
 }
@@ -1174,6 +1186,23 @@ void ApplyLegacyVisibility(GUIMain &gui, LegacyGUIVisState vis)
     }
 }
 
+void SetExcludedFromDisabled(GUIObject *gc, bool on)
+{
+    if (on)
+    {
+        Context.GuiControlExcludedFromDisabled = gc->Id;
+        Context.GuiExcludedFromDisabled = gc->ParentId;
+    }
+    else
+    {
+        Context.GuiControlExcludedFromDisabled = -1;
+        Context.GuiExcludedFromDisabled = -1;
+    }
+
+    if (Context.DisabledState != kGuiDis_Undefined && Context.DisabledState != kGuiDis_Unchanged)
+        gc->MarkChanged();
+}
+
 } // namespace GUI
 
 } // namespace Common
