@@ -282,7 +282,7 @@ namespace AGS.Editor.Components
             }
             catch (ApplicationException ex)
             {
-                _guiController.ShowMessage("An error occurred exporting the character file. The error was: " + ex.Message, MessageBoxIcon.Warning);
+                _guiController.ShowError("An error occurred exporting the character file.", ex, MessageBoxIcon.Warning);
             }
         }
 
@@ -308,7 +308,7 @@ namespace AGS.Editor.Components
             }
             catch (ApplicationException ex)
             {
-                _guiController.ShowMessage("An error occurred importing the character file. The error was: " + Environment.NewLine + Environment.NewLine + ex.Message, MessageBoxIcon.Warning);
+                _guiController.ShowError("An error occurred importing the character file.", ex, MessageBoxIcon.Warning);
             }
         }        
 
