@@ -261,7 +261,7 @@ namespace AGS.Editor.Components
             }
             catch (CannotDeleteFileException ex)
             {
-                _guiController.ShowMessage("The room file could not be deleted." + Environment.NewLine + Environment.NewLine + ex.Message, MessageBoxIcon.Warning);
+                _guiController.ShowError("The room file could not be deleted.", ex, MessageBoxIcon.Warning);
             }
             RoomListTypeConverter.SetRoomList(_agsEditor.CurrentGame.Rooms);
             _agsEditor.CurrentGame.FilesAddedOrRemoved = true;
@@ -427,7 +427,7 @@ namespace AGS.Editor.Components
             }
             catch (Exception ex)
             {
-                _guiController.ShowMessage("There was a problem importing the room file: " + ex.Message, MessageBoxIcon.Warning);
+                _guiController.ShowError("There was a problem importing the room file.", ex, MessageBoxIcon.Warning);
             }
         }
 
@@ -447,7 +447,7 @@ namespace AGS.Editor.Components
             }
             catch (AGSEditorException ex)
             {
-                _guiController.ShowMessage("There was an error saving the script for room " + roomFile + ": " + ex.Message, MessageBoxIcon.Warning);
+                _guiController.ShowError("There was an error saving the script for room " + roomFile + ".", ex, MessageBoxIcon.Warning);
             }
         }
 
@@ -465,7 +465,7 @@ namespace AGS.Editor.Components
                 }
                 catch (Exception ex)
                 {
-                    _guiController.ShowMessage("The existing file could not be deleted." + Environment.NewLine + Environment.NewLine + ex.Message, MessageBoxIcon.Warning);
+                    _guiController.ShowError("The existing file could not be deleted.", ex, MessageBoxIcon.Warning);
                     return false;
                 }
             }
@@ -525,7 +525,7 @@ namespace AGS.Editor.Components
             }
             catch (Exception ex)
             {
-                _guiController.ShowMessage("There was an error attempting to create the new room. The error was: " + ex.Message, MessageBoxIcon.Warning);
+                _guiController.ShowError("There was an error attempting to create the new room.", ex, MessageBoxIcon.Warning);
             }
         }
 
@@ -622,6 +622,8 @@ namespace AGS.Editor.Components
         {
             foreach (RoomHotspot hotspot in room.Hotspots)
             {
+                if (string.IsNullOrEmpty(hotspot.Name))
+                    continue;
                 if (_agsEditor.CurrentGame.IsScriptNameAlreadyUsed(hotspot.Name, hotspot) ||
                     room.IsScriptNameAlreadyUsed(hotspot.Name, hotspot))
                 {
@@ -630,6 +632,8 @@ namespace AGS.Editor.Components
             }
             foreach (RoomObject obj in room.Objects)
             {
+                if (string.IsNullOrEmpty(obj.Name))
+                    continue;
                 if (_agsEditor.CurrentGame.IsScriptNameAlreadyUsed(obj.Name, obj) ||
                     room.IsScriptNameAlreadyUsed(obj.Name, obj))
                 {
