@@ -367,6 +367,8 @@ int run_dialog_script(int dialogID, int offse, int optionIndex)
     // the line below fixes the problem with the close-up face remaining on the
     // screen after they finish talking; however, it makes the dialog options
     // area flicker when going between topics.
+    // FIXME: find a better solution rather than disable/enable iface?
+    // this causes all gui texture reupdate twice, and other things...
     DisableInterface();
     UpdateGameOnce(); // redraw the screen to make sure it looks right
     EnableInterface();
@@ -594,7 +596,7 @@ DialogOptions::~DialogOptions()
 void DialogOptions::Show()
 {
     Begin();
-    Draw();
+    Draw(); // prepare the options texture prior to the first Run()
     while (Run());
     End();
 }
@@ -725,6 +727,10 @@ void DialogOptions::Begin()
     needRedraw = false;
     wantRefresh = false;
     mouseison=-10;
+
+    // Disable rest of the game interface while the dialog options are displayed;
+    // note that this also disables "overhotspot" labels update
+    DisableInterfaceEx(false /* don't change cursor */);
 }
 
 void DialogOptions::Draw()
@@ -923,13 +929,6 @@ void DialogOptions::Draw()
       ddb = gfxDriver->CreateDDBFromBitmap(subBitmap.get(), options_surface_has_alpha, false);
     else
       gfxDriver->UpdateDDBFromBitmap(ddb, subBitmap.get(), options_surface_has_alpha);
-
-    if (runGameLoopsInBackground)
-    {
-        DisableInterfaceEx(false /* don't change cursor */);
-        render_graphics(ddb, dirtyx, dirtyy);
-        EnableInterfaceEx(false /* don't change cursor */);
-    }
 }
 
 bool DialogOptions::Run()
@@ -937,21 +936,27 @@ bool DialogOptions::Run()
     // Run() can be called in a loop, so keep events going.
     sys_evt_process_pending();
 
-    // Disable interface prior to updating & rendering the game in background;
-    // not that this also disables "overhotspot" labels
-    DisableInterfaceEx(false /* don't change cursor */);
     // Optionally run full game update, otherwise only minimal auto & overlay update
+    // NOTE: the redrawing of the dialog options themselves is a bit off here in this code:
+    // it happens AFTER we update the rest of the game, and stored on the dialog options
+    // texture, which will become updated on screen during the *next* Run().
+    // But technically there's no wait between options redraw and next update.
+    // The wait is between update and next options redraw... We might benefit from
+    // another code restructure here.
     if (runGameLoopsInBackground)
     {
         UpdateGameOnce(false, ddb, dirtyx, dirtyy);
     }
     else
     {
+        update_polled_stuff();
         update_audio_system_on_game_loop();
         UpdateCursorAndDrawables();
         render_graphics(ddb, dirtyx, dirtyy);
+
+        if (!play.fast_forward)
+            WaitForNextFrame();
     }
-    EnableInterfaceEx(false /* don't change cursor */);
 
     // Stop the dialog options if wsa requested from script
     if (doStop)
@@ -1096,12 +1101,6 @@ bool DialogOptions::Run()
     if (needRedraw)
         Draw();
 
-    // Go for another options loop round
-    update_polled_stuff();
-    if (!runGameLoopsInBackground && (play.fast_forward == 0))
-    { // NOTE: if runGameLoopsInBackground then it's called inside UpdateGameOnce
-        WaitForNextFrame();
-    }
     return true; // continue running loop
 }
 
@@ -1291,6 +1290,9 @@ void DialogOptions::End()
   // In case it's the QFG4 style dialog, remove the black screen
   play.in_conversation--;
   remove_screen_overlay(OVER_COMPLETE);
+
+  // Re-enabled the game GUI
+  EnableInterfaceEx(false /* don't change cursor */);
 }
 
 int run_dialog_entry(int dlgnum)
@@ -1498,6 +1500,8 @@ void DialogExec::Run()
             if (said_speech_line > 0)
             {
                 // fix the problem with the close-up face remaining on screen
+                // FIXME: find a better solution rather than disable/enable iface?
+                // this causes all gui texture reupdate twice, and other things...
                 DisableInterface();
                 UpdateGameOnce(); // redraw the screen to make sure it looks right
                 EnableInterface();
