@@ -282,25 +282,24 @@ Bitmap *create_textual_image(const char *text, const DisplayTextLooks &look, col
     {
         // Textual overlay purposed for character speech
         int ttxleft = 0, ttxtop = paddingScaled, oriwid = wii - padding * 2;
-        int drawBackground = 0;
+        bool draw_background = false;
 
         DisplayTextLooks fix_look = look;
         if (use_speech_textwindow)
         {
-            drawBackground = 1;
+            draw_background = true;
         }
         else if (use_thought_gui)
         {
             // make it treat it as drawing inside a window now
             fix_look.Style = kDisplayTextStyle_TextWindow;
-            drawBackground = 1;
+            draw_background = true;
         }
 
-        if (drawBackground)
+        if (draw_background)
         {
-            text_color = 15; // use fixed standard color here
             draw_text_window_and_bar(&text_window_ds, wantFreeScreenop, topbar, disp,
-                &ttxleft, &ttxtop, &adjustedXX, &adjustedYY, &wii, &text_color, 0, usingGui);
+                &ttxleft, &ttxtop, &adjustedXX, &adjustedYY, &wii, nullptr, 0, usingGui);
             if (usingGui > 0)
             {
                 alphaChannel = guis[usingGui].HasAlphaChannel();
@@ -344,7 +343,7 @@ Bitmap *create_textual_image(const char *text, const DisplayTextLooks &look, col
     {
         // Textual overlay purposed for the standard message box
         int xoffs, yoffs, oriwid = wii - padding * 2;
-        text_color = 15; // use fixed standard color here
+        text_color = 15; // use standard text box color here (may be adjusted inside draw_text_window)
         draw_text_window_and_bar(&text_window_ds, wantFreeScreenop, topbar, disp, &xoffs, &yoffs, &adjustedXX, &adjustedYY, &wii, &text_color);
         text_color = text_window_ds->GetCompatibleColor(text_color);
 
@@ -646,23 +645,30 @@ void wouttextxy_AutoOutline(Bitmap *ds, size_t font, int32_t color, const char *
         color |= makeacol32(0, 0, 0, 0xff);
 
     const int t_width = get_text_width(texx, font);
-    const auto t_extent = get_font_surface_extent(font);
-    const int t_height = t_extent.second - t_extent.first;
+    // Horizontal extent lets us know if any glyphs have negative horizontal offset
+    const auto t_extent_hor = get_font_surface_hextent(font);
+    const auto t_extent_ver = get_font_surface_vextent(font);
+    const int t_height = t_extent_ver.second - t_extent_ver.first + 1;
     if (t_width == 0 || t_height == 0)
         return;
     // Prepare stencils
-    const int t_yoff = t_extent.first;
+    const int t_xoff = (t_extent_hor < 0 ? t_extent_hor : 0);
+    const int t_yoff = t_extent_ver.first;
     Bitmap *texx_stencil, *outline_stencil;
     alloc_font_outline_buffers(font, &texx_stencil, &outline_stencil,
-        t_width, t_height, stencil_cd);
+        t_width + (-t_xoff) * 2, t_height, stencil_cd);
     texx_stencil->ClearTransparent();
     outline_stencil->ClearTransparent();
     // Ready text stencil
-    // Note we are drawing with y off, in case some font's glyphs exceed font's ascender
-    wouttextxy(texx_stencil, 0, -t_yoff, font, color, texx);
+    // Note we are drawing with x off, in case some glyphs have negative offsets
+    // and appear further to the left (we create stencil with extra space in that case);
+    // and y off, in case some font's glyphs exceed font's ascender
+    // NOTE: t_xoff here will only fix the outline, but this won't resolve e.g. parts
+    // of leftmost glyph positioned outside of a gui control or an overlay.
+    wouttextxy(texx_stencil, -t_xoff, -t_yoff, font, color, texx);
     // Anti-aliased TTFs require to be alpha-blended, not blit,
     // or the alpha values will be plain copied and final image will be broken.
-    void(Bitmap::*pfn_drawstencil)(Bitmap *src, int dst_x, int dst_y);
+    void(Bitmap::*pfn_drawstencil)(const Bitmap *src, int dst_x, int dst_y);
     if (antialias)
     { // NOTE: we must set out blender AFTER wouttextxy, or it will be overidden
         set_argb2any_blender();
@@ -673,11 +679,12 @@ void wouttextxy_AutoOutline(Bitmap *ds, size_t font, int32_t color, const char *
         pfn_drawstencil = &Bitmap::MaskedBlit;
     }
 
-    // move start of text so that the outline doesn't drop off the bitmap
-    xxp += thickness;
+    // move start of text so that the outline doesn't drop off the bitmap;
+    // move by glyph offset in case the stencil was drawn with offset
+    xxp += thickness + t_xoff;
     int const outline_y = yyp + t_yoff;
     yyp += thickness;
-    
+
     // What we do here: first we paint text onto outline_stencil offsetting vertically;
     // then we paint resulting outline_stencil onto final dest offsetting horizontally.
     int largest_y_diff_reached_so_far = -1; 
@@ -705,6 +712,8 @@ void wouttextxy_AutoOutline(Bitmap *ds, size_t font, int32_t color, const char *
         if (x_diff > 0)
             (ds->*pfn_drawstencil)(outline_stencil, xxp + x_diff, outline_y);
     }
+
+    xxp -= t_xoff; // remove glyph offset from the final text position (keep std text pos)
 }
 
 // Draw an outline if requested, then draw the text on top 
@@ -884,15 +893,18 @@ void draw_text_window(Bitmap **text_window_ds, bool should_free_ds,
         ifnum = game.options[OPT_TWCUSTOM];
 
     // Assertions
-    if (ifnum >= game.numgui)
+    if (ifnum > 0)
     {
-        debug_script_warn("Invalid GUI %d specified as text window (valid range: 1..%d)", ifnum, game.numgui);
-        ifnum = 0;
-    }
-    else if (!guis[ifnum].IsTextWindow())
-    {
-        debug_script_warn("GUI %d is set as text window but is not actually a text window GUI", ifnum);
-        ifnum = 0;
+        if (ifnum >= game.numgui)
+        {
+            debug_script_warn("Invalid GUI %d specified as text window (valid range: 1..%d)", ifnum, game.numgui);
+            ifnum = 0;
+        }
+        else if (!guis[ifnum].IsTextWindow())
+        {
+            debug_script_warn("GUI %d is set as text window but is not actually a text window GUI", ifnum);
+            ifnum = 0;
+        }
     }
 
     if (ifnum <= 0)
