@@ -174,9 +174,12 @@ void SeekMIDIPosition (int position) {
     if (play.silent_midi == 0 && current_music_type != MUS_MIDI)
         return;
 
-    auto *ch = AudioChans::GetChannel(SCHAN_MUSIC);
-    ch->seek(position);
-    debug_script_log("Seek MIDI position to %d", position);
+    auto *ch = AudioChans::GetChannel(play.silent_midi == 0 ? SCHAN_MUSIC : play.silent_midi_channel);
+    if (ch)
+    {
+        ch->seek(position);
+        debug_script_log("Seek MIDI position to %d", position);
+    }
 }
 
 int GetMIDIPosition () {
@@ -185,7 +188,7 @@ int GetMIDIPosition () {
     if (play.silent_midi == 0 && current_music_type != MUS_MIDI)
         return -1; // returns -1 on failure according to old manuals
     
-    auto* ch = AudioChans::GetChannelIfPlaying(SCHAN_MUSIC);
+    auto* ch = AudioChans::GetChannelIfPlaying(play.silent_midi == 0 ? SCHAN_MUSIC : play.silent_midi_channel);
     if (ch) {
         return ch->get_pos();
     }
@@ -390,9 +393,8 @@ void PlaySilentMIDI (int mnum) {
     if (current_music_type == MUS_MIDI)
         quit("!PlaySilentMIDI: proper midi music is in progress");
 
-    play.silent_midi = mnum;
-    play.silent_midi_channel = SCHAN_SPEECH;
-    stop_and_destroy_channel(play.silent_midi_channel);
+    const int silent_midi_chan = SCHAN_SPEECH;
+    stop_and_destroy_channel(silent_midi_chan);
     // No idea why it uses speech voice channel, but since it does (and until this is changed)
     // we have to correctly reset speech voice in case there was a nonblocking speech
     if (play.IsNonBlockingVoiceSpeech())
@@ -401,17 +403,15 @@ void PlaySilentMIDI (int mnum) {
     std::unique_ptr<SoundClip> clip = load_sound_clip_from_old_style_number(true, mnum, false);
     if (clip == nullptr)
     {
-        quitprintf("!PlaySilentMIDI: failed to load aMusic%d", mnum);
-    }
-    if (clip->play())
-    {
-        clip->set_volume100(0);
-        AudioChans::SetChannel(play.silent_midi_channel, std::move(clip));
-    }
-    else
-    {
-        quitprintf("!PlaySilentMIDI: failed to play aMusic%d", mnum);
+        debug_script_warn("PlaySilentMIDI: music file 'aMusic%d' not found or cannot be read", mnum);
+        return;
     }
+    
+    clip->set_volume100(0);
+    clip->play();
+    AudioChans::SetChannel(silent_midi_chan, std::move(clip));
+    play.silent_midi = mnum;
+    play.silent_midi_channel = silent_midi_chan;
 }
 
 void SetSpeechVolume(int newvol) {
