@@ -481,7 +481,7 @@ int GetGameParameter (int parm, int data1, int data2, int data3) {
    case GP_FRAMESOUND:
    case GP_ISFRAMEFLIPPED:
        {
-           AssertFrame("GetGameParameter", data1 - 1, data2, data3);
+           AssertFrame("GetGameParameter", "", data1 - 1, data2, data3);
 
            ViewFrame *pvf = &views[data1 - 1].loops[data2].frames[data3];
 
@@ -586,8 +586,10 @@ int SetGameOption (int opt, int newval) {
         break;
     case OPT_DISABLEOFF:
         GUI::Options.DisabledStyle = static_cast<GuiDisableStyle>(game.options[OPT_DISABLEOFF]);
-        // If GUI was disabled at this time then also update it, as visual style could've changed
-        if (play.disabled_user_interface > 0) { GUIE::MarkAllGUIForUpdate(true, false); }
+        // If interface was disabled at this time then also update GUIs, as visual style could've changed
+        update_gui_disabled_status();
+        // Also update all disabled controls (like buttons), in case they need to update their disabled effect
+        GUIE::MarkDisabledGUIForUpdate();
         break;
     case OPT_CROSSFADEMUSIC:
         if (game.audioClipTypes.size() > AUDIOTYPE_LEGACY_MUSIC)
@@ -1029,7 +1031,7 @@ int WaitImpl(int skip_type, int nloops)
     if (play.fast_forward && ((skip_type & ~SKIP_AUTOTIMER) != 0))
         return 0;
 
-    // < 3.6.0 treated negative nloops as "no time";
+    // < 3.6.0 scripts treated negative nloops as "no time";
     // also old engine let nloops to overflow into neg when assigned to wait_counter...
     if (game.options[OPT_BASESCRIPTAPI] < kScriptAPI_v360)
     {
@@ -1037,6 +1039,17 @@ int WaitImpl(int skip_type, int nloops)
             nloops = 0;
     }
 
+    // Zero loops make no sense, however very old engines seem to
+    // accidentally produce a "wait one tick" effect.
+    // v2.62 was the first engine to report error on Wait(0).
+    if (nloops == 0)
+    {
+        if (loaded_game_file_version < kGameVersion_262)
+            nloops = 1;
+        else
+            return 0;
+    }
+
     // clamp to int16
     play.wait_counter = static_cast<int16_t>(Math::Clamp<int>(nloops, -1, INT16_MAX));
     play.wait_skipped_by = SKIP_NONE;
