@@ -168,6 +168,19 @@ void MarkInventoryForUpdate(int char_id, bool is_player)
     }
 }
 
+void MarkDisabledGUIForUpdate()
+{
+    for (auto &gui : guis)
+    {
+        for (int i = 0; i < gui.GetControlCount(); ++i)
+        {
+            auto *gc = gui.GetControl(i);
+            if (!gc->IsEnabled())
+                gc->MarkChanged();
+        }
+    }
+}
+
 } // namespace GUI
 } // namespace Engine
 } // namespace AGS
@@ -461,9 +474,11 @@ void process_interface_click(int ifce, int btn, int mbut) {
         GUIObject *theObj = guis[ifce].GetControl(btn);
         // if the object has a special handler script then run it;
         // otherwise, run interface_click
+        // FIXME: do not call DoesScriptFunctionExist* every time, remember last result,
+        // similar to the interaction event handler test.
         if ((theObj->GetEventCount() > 0) &&
             (!theObj->EventHandlers[0].IsEmpty()) &&
-            DoesScriptFunctionExistInModules(theObj->EventHandlers[0]))
+            DoesScriptFunctionExistInModule(guis[ifce].ScriptModule, theObj->EventHandlers[0]))
         {
             // control-specific event handler
             const ScriptFunctionRef fn_ref(guis[ifce].ScriptModule, theObj->EventHandlers[0]);
@@ -621,8 +636,10 @@ void update_gui_disabled_status()
     if (disabled_state_was != GUI::Context.DisabledState)
     {
         // Mark guis for redraw and reset control-under-mouse detection
-        GUIE::MarkAllGUIForUpdate(GUI::Options.DisabledStyle != kGuiDis_Unchanged, true);
-        if (GUI::Options.DisabledStyle != kGuiDis_Unchanged)
+        const bool keep_visuals = (disabled_state_was == kGuiDis_Undefined || disabled_state_was == kGuiDis_Unchanged)
+            && (GUI::Context.DisabledState == kGuiDis_Undefined || GUI::Context.DisabledState == kGuiDis_Unchanged);
+        GUIE::MarkAllGUIForUpdate(!keep_visuals, true);
+        if (!keep_visuals)
         {
             invalidate_screen();
         }
@@ -642,8 +659,8 @@ static bool should_skip_adjust_for_gui(const GUIMain &gui)
 
 int adjust_x_for_guis(int x, int y, bool assume_blocking)
 {
-    if ((game.options[OPT_DISABLEOFF] == kGuiDis_Off) &&
-        ((GUI::Context.DisabledState != kGuiDis_Undefined) || assume_blocking))
+    if ((GUI::Options.DisabledStyle == kGuiDis_Off) &&
+        (!IsInterfaceEnabled() || assume_blocking))
         return x; // All GUI off (or will be when the message is displayed)
     // If it's covered by a GUI, move it right a bit
     // FIXME: should not we also account for the text's width here?
@@ -670,8 +687,8 @@ int adjust_x_for_guis(int x, int y, bool assume_blocking)
 
 int adjust_y_for_guis(int y, bool assume_blocking)
 {
-    if ((game.options[OPT_DISABLEOFF] == kGuiDis_Off) &&
-        ((GUI::Context.DisabledState >= 0) || assume_blocking))
+    if ((GUI::Options.DisabledStyle == kGuiDis_Off) &&
+        (!IsInterfaceEnabled() || assume_blocking))
         return y; // All GUI off (or will be when the message is displayed)
     // If it's covered by a GUI, move it down a bit
     // FIXME: should not we also account for the text's height here?
@@ -693,9 +710,9 @@ int adjust_y_for_guis(int y, bool assume_blocking)
     return y;
 }
 
-int gui_get_interactable(int x,int y)
+int gui_get_interactable(int x, int y)
 {
-    if ((game.options[OPT_DISABLEOFF] == kGuiDis_Off) && (GUI::Context.DisabledState >= 0))
+    if (GUI::Context.DisabledState == kGuiDis_Off)
         return -1;
     return GetGUIAt(x, y);
 }
