@@ -59,18 +59,25 @@ Bitmap *CursorGraphicState::GetImage() const
     return _genImage != nullptr ? _genImage.get() : spriteset[_sprnum];
 }
 
+void CursorGraphicState::ResetImage()
+{
+    _genImage.reset();
+    _sprnum = -1;
+    _hasAlpha = false;
+}
+
 void CursorGraphicState::SetImage(std::unique_ptr<Common::Bitmap> pic, bool has_alpha)
 {
+    ResetImage();
     _genImage = std::move(pic);
     _hasAlpha = has_alpha;
-    _sprnum = -1;
     MarkChanged();
 }
 
 void CursorGraphicState::SetSpriteNum(int sprnum)
 {
+    ResetImage();
     _sprnum = sprnum;
-    _genImage.reset();
     _hasAlpha = (game.SpriteInfos[sprnum].Flags & SPF_ALPHACHANNEL) != 0;
     MarkChanged();
 }
