@@ -334,8 +334,10 @@ void unload_old_room()
     play.bg_frame_locked = 0;
     remove_all_overlays();
     raw_saved_screen = nullptr;
-    for (int ff = 0; ff < MAX_ROOM_BGFRAMES; ff++)
-        play.raw_modified[ff] = 0;
+    for (int i = 0; i < MAX_ROOM_BGFRAMES; ++i)
+        play.room_bg_modified[i] = false;
+    for (int i = 0; i < kNumRoomAreaTypes; ++i)
+        play.room_mask_modified[i] = false;
     for (size_t i = 0; i < thisroom.LocalVariables.size() && i < MAX_INTERACTION_VARIABLES; ++i)
         croom->interactionVariableValues[i] = thisroom.LocalVariables[i].Value;
 
@@ -595,8 +597,10 @@ void load_new_room(int newnum, CharacterInfo *forchar)
         }
     }
 
-    for (size_t i = 0; i < thisroom.BgFrameCount; ++i) {
-        thisroom.BgFrames[i].Graphic = PrepareSpriteForUse(thisroom.BgFrames[i].Graphic, false /* no alpha */, false /* no keep mask */);
+    for (size_t i = 0; i < thisroom.BgFrameCount; ++i)
+    {
+        thisroom.BgFrames[i].Graphic = PrepareSpriteForUse(
+            thisroom.BgFrames[i].Graphic, false /* no alpha */, false /* no keep mask */, thisroom.BgFrames[i].Palette);
     }
 
     set_our_eip(202);
@@ -737,17 +741,14 @@ void load_new_room(int newnum, CharacterInfo *forchar)
     for (uint32_t cc = 0; cc < thisroom.Objects.size(); cc++)
     {
         // export the object's script object
-        if (thisroom.Objects[cc].ScriptName.IsEmpty())
-            continue;
-        ccAddExternalScriptObject(thisroom.Objects[cc].ScriptName, &scrObj[cc], &ccDynamicObject);
+        if (!thisroom.Objects[cc].ScriptName.IsEmpty())
+            ccAddExternalScriptObject(thisroom.Objects[cc].ScriptName, &scrObj[cc], &ccDynamicObject);
     }
 
     for (int cc = 0; cc < MAX_ROOM_HOTSPOTS; cc++)
     {
-        if (thisroom.Hotspots[cc].ScriptName.IsEmpty())
-            continue;
-
-        ccAddExternalScriptObject(thisroom.Hotspots[cc].ScriptName, &scrHotspot[cc], &ccDynamicHotspot);
+        if (!thisroom.Hotspots[cc].ScriptName.IsEmpty())
+            ccAddExternalScriptObject(thisroom.Hotspots[cc].ScriptName, &scrHotspot[cc], &ccDynamicHotspot);
     }
 
     set_our_eip(210);
