@@ -308,6 +308,11 @@ HSaveError OpenSavegameBase(const String &filename, SavegameSource *src, Savegam
     return err;
 }
 
+bool DoesSavegameExist(const String &filename)
+{
+    return File::IsFile(filename);
+}
+
 HSaveError OpenSavegame(const String &filename, SavegameSource &src, SavegameDescription &desc, SavegameDescElem elems)
 {
     return OpenSavegameBase(filename, &src, &desc, elems);
@@ -708,7 +713,17 @@ HSaveError DoAfterRestore(const PreservedParams &pp, RestoredData &r_data, SaveC
         {
             if (r_data.RoomBkgScene[i])
             {
-                thisroom.BgFrames[i].Graphic = r_data.RoomBkgScene[i];
+                // Blit, don't replace image, in case we restored a image of different size
+                thisroom.BgFrames[i].Graphic->Blit(r_data.RoomBkgScene[i].get());
+            }
+        }
+
+        for (int i = 0; i < kNumRoomAreaTypes; ++i)
+        {
+            if (r_data.RoomMask[i])
+            {
+                // Blit, don't replace image, in case we restored a image of different size
+                thisroom.SetMask(static_cast<RoomAreaMask>(i), r_data.RoomMask[i].get());
             }
         }
 
