@@ -18,6 +18,8 @@
 //=============================================================================
 #ifndef __AGS_EE_GFX__SDLRENDERERFILTER_H
 #define __AGS_EE_GFX__SDLRENDERERFILTER_H
+
+#include <SDL_render.h>
 #include "gfx/gfxfilter_scaling.h"
 
 namespace AGS
@@ -32,6 +34,9 @@ class SDLRendererGfxFilter : public ScalingGfxFilter
 public:
     const GfxFilterInfo &GetInfo() const override;
 
+    virtual SDL_ScaleMode GetScaleMode() const;
+    virtual void InitSDLHint() const;
+
     static const GfxFilterInfo FilterInfo;
 };
 
