@@ -174,6 +174,13 @@ public:
     // Update the state during a game tick
     bool Run() override
     {
+        // If skipping cutscene and expecting user input: don't wait at all
+        if (play.fast_forward && (play.wait_counter != 0) && ((play.key_skip_wait & ~SKIP_AUTOTIMER) != 0))
+        {
+            play.SetWaitSkipResult(SKIP_NONE);
+            return false;
+        }
+
         GameTick();
         return ShouldStayInWaitMode();
     }
@@ -513,8 +520,8 @@ bool run_service_key_controls(KeyInput &out_key)
     }
 
     if ((agskey == eAGSKeyCodeCtrlE) && (display_fps == kFPS_Forced)) {
-        // if --fps paramter is used, Ctrl+E will max out frame rate
-        setTimerFps(isTimerFpsMaxed() ? frames_per_second : 1000);
+        // if --fps parameter is used, Ctrl+E will toggle maxed out frame rate
+        setTimerFps(frames_per_second, !isTimerFpsMaxed());
         return false;
     }
 
@@ -639,7 +646,7 @@ static void check_keyboard_controls()
     // it should be either a printable character or one of the textbox control keys
     // TODO: instead of making a preliminary check, just let each gui control
     // test the key and OnKeyPress return if it was handled?
-    if ((GUI::Context.DisabledState == kGuiDis_Undefined) &&
+    if (GUI::IsEnabledState() &&
         ((ki.UChar > 0) || ((agskey >= 32) && (agskey <= 255)) ||
          (agskey == eAGSKeyCodeReturn) || (agskey == eAGSKeyCodeBackspace))) {
         for (int guiIndex = 0; guiIndex < game.numgui; guiIndex++) {
@@ -827,11 +834,6 @@ static void update_cursor_over_gui()
     {
         if (!gui.IsDisplayed()) continue; // not on screen
         if (!gui.IsClickable()) continue; // don't update non-clickable
-        // Don't touch GUI if "GUIs Turn Off When Disabled"
-        if ((game.options[OPT_DISABLEOFF] == kGuiDis_Off) &&
-            (GUI::Context.DisabledState >= 0) &&
-            (gui.PopupStyle != kGUIPopupNoAutoRemove))
-            continue;
         gui.Poll(mousex, mousey);
     }
 }
@@ -842,28 +844,27 @@ extern int mouse_frame, mouse_delay;
 static void update_cursor_view()
 {
     // update animating mouse cursor
-    if (game.mcurs[cur_cursor].view >= 0) {
+    const auto &mcur = game.mcurs[cur_cursor];
+    if (mcur.view >= 0 && mcur.view < game.numviews)
+    {
         // only on mousemove, and it's not moving
-        if (((game.mcurs[cur_cursor].flags & MCF_ANIMMOVE) != 0) &&
+        if (((mcur.flags & MCF_ANIMMOVE) != 0) &&
             (mousex == lastmx) && (mousey == lastmy));
         // only on hotspot, and it's not on one
-        else if (((game.mcurs[cur_cursor].flags & MCF_HOTSPOT) != 0) &&
+        else if (((mcur.flags & MCF_HOTSPOT) != 0) &&
             (GetLocationType(game_to_data_coord(mousex), game_to_data_coord(mousey)) == 0))
-            set_new_cursor_graphic(game.mcurs[cur_cursor].pic);
+            set_new_cursor_graphic(mcur.pic);
         else if (mouse_delay>0) mouse_delay--;
-        else {
-            int viewnum = game.mcurs[cur_cursor].view;
-            int loopnum = 0;
-            if (loopnum >= views[viewnum].numLoops)
-                quitprintf("An animating mouse cursor is using view %d which has no loops", viewnum + 1);
-            if (views[viewnum].loops[loopnum].numFrames < 1)
-                quitprintf("An animating mouse cursor is using view %d which has no frames in loop %d", viewnum + 1, loopnum);
-
+        // only animate if the loop 0 exists and has frames
+        else if (views[mcur.view].numLoops > 0 && views[mcur.view].loops[0].numFrames > 0)
+        {
+            const int viewnum = mcur.view;
+            const int loopnum = 0;
             mouse_frame++;
             if (mouse_frame >= views[viewnum].loops[loopnum].numFrames)
                 mouse_frame = 0;
             set_new_cursor_graphic(views[viewnum].loops[loopnum].frames[mouse_frame].pic);
-            mouse_delay = views[viewnum].loops[loopnum].frames[mouse_frame].speed + game.mcurs[cur_cursor].animdelay;
+            mouse_delay = views[viewnum].loops[loopnum].frames[mouse_frame].speed + mcur.animdelay;
             CheckViewFrame(viewnum, loopnum, mouse_frame);
         }
         lastmx = mousex; lastmy = mousey;
@@ -972,6 +973,9 @@ static void game_loop_update_fps()
 float get_game_fps() {
     // if we have maxed out framerate then return the frame rate we're seeing instead
     // fps must be greater that 0 or some timings will take forever.
+    // TODO: review this, consider always returning fixed property here,
+    // and use get_real_fps() whenever we need real time;
+    // but must double check all situations where this function is used!
     if (isTimerFpsMaxed() && fps > 0.0f) {
         return fps;
     }
@@ -1007,10 +1011,6 @@ void UpdateGameOnce(bool checkControls, IDriverDependantBitmap *extraBitmap, int
     if ((play.no_hicolor_fadein) && (game.options[OPT_FADETYPE] == kScrTran_Fade))
         play.screen_is_faded_out = 0;
 
-    set_our_eip(1014);
-
-    update_gui_disabled_status();
-
     set_our_eip(1004);
 
     game_loop_do_early_script_update();
@@ -1023,7 +1023,7 @@ void UpdateGameOnce(bool checkControls, IDriverDependantBitmap *extraBitmap, int
     if (!game_loop_check_ground_level_interactions())
         return; // update interrupted
 
-    mouse_on_iface=-1;
+    mouse_on_iface=-1; // FIXME: why is this here? move to a related update function!
 
     check_debug_keys();
 
@@ -1035,6 +1035,7 @@ void UpdateGameOnce(bool checkControls, IDriverDependantBitmap *extraBitmap, int
     // update gui under mouse; this also updates gui control focus;
     // atm we must call this before "check_controls", because GUI interaction
     // relies on remembering which control was focused by the cursor prior
+    update_gui_disabled_status();
     update_cursor_over_gui();
     // handle actual input (keys, mouse, and so forth)
     game_loop_check_controls(checkControls);
@@ -1058,7 +1059,10 @@ void UpdateGameOnce(bool checkControls, IDriverDependantBitmap *extraBitmap, int
 
     // Only render if we are not skipping a cutscene
     if (!play.fast_forward)
+    {
+        update_gui_disabled_status(); // in case they changed it in the late script update
         render_graphics(extraBitmap, extraX, extraY);
+    }
 
     set_our_eip(6);
 
